@@ -1,4 +1,4 @@
-# Copyright 1999-2004 Gentoo Foundation
+# Copyright 1999-2006 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 # $Id: /var/cvsroot/gentoo-src/portage/pym/emergehelp.py,v 1.8.2.2 2005/01/16 02:35:33 carpaski Exp $
 
@@ -14,9 +14,9 @@ def shorthelp():
 	print "   "+turquoise("emerge")+" [ "+green("options")+" ] [ "+green("action")+" ] < "+turquoise("system")+" | "+turquoise("world")+" >"
 	print "   "+turquoise("emerge")+" < "+turquoise("--sync")+" | "+turquoise("--metadata")+" | "+turquoise("--info")+" >"
 	print "   "+turquoise("emerge")+" "+turquoise("--resume")+" [ "+green("--pretend")+" | "+green("--ask")+" | "+green("--skipfirst")+" ]"
-	print "   "+turquoise("emerge")+" "+turquoise("--help")+" [ "+green("system")+" | "+green("config")+" | "+green("sync")+" ] "
-	print bold("Options:")+" "+green("-")+"["+green("abcCdDefhikKlnNoOpPsSuUvV")+"] ["+green("--oneshot")+"] ["+green("--newuse")+"] ["+green("--noconfmem")+"]"
-	print      "                                    ["+green("--columns")+"] ["+green("--nospinner")+"]"
+	print "   "+turquoise("emerge")+" "+turquoise("--help")+" [ "+green("system")+" | "+green("world")+" | "+green("config")+" | "+green("--sync")+" ] "
+	print bold("Options:")+" "+green("-")+"["+green("abBcCdDefgGhikKlnNoOpqPsStuvV")+"] ["+green("--oneshot")+"] ["+green("--newuse")+"] ["+green("--noconfmem")+"]"
+	print      "                                          ["+green("--columns")+"] ["+green("--nocolor")+"] ["+green("--nospinner")+"]"
 	print bold("Actions:")+" [ "+green("--clean")+" | "+green("--depclean")+" | "+green("--prune")+" | "+green("--regen")+" | "+green("--search")+" | "+green("--unmerge")+" ]"
 	print
 
@@ -56,6 +56,11 @@ def help(myaction,myopts,havecolor=1):
 		print "              "+bold("<=sys-devel/binutils-2.11.92.0.12.3-r1")+" matches"
 		print "                  binutils-2.11.90.0.7 and binutils-2.11.92.0.12.3-r1"
 		print
+		print "       "+green("--config")
+		print "              Runs package-specific operations that must be executed after an"
+		print "              emerge process has completed.  This usually entails configuration"
+		print "              file setup or other similar setups that the user may wish to run."
+		print
 		print "       "+green("--depclean")
 		print "              Cleans the system by removing packages that are not associated"
 		print "              with explicitly merged packages. Depclean works by creating the"
@@ -75,9 +80,9 @@ def help(myaction,myopts,havecolor=1):
 		print "              run with the '--verbose' flag."
 		print
 		print "       "+green("--metadata")
-		print "              Causes portage to process all the metacache files as is normally done"
-		print "              on the tail end of an rsync update using "+bold("emerge --sync")+". The"
-		print "              processing creates the cache database that portage uses for"
+		print "              Causes portage to process all the metacache files as is normally "
+		print "              done on the tail end of an rsync update using "+bold("emerge --sync")+"."
+		print "              This processing creates the cache database that portage uses for"
 		print "              pre-parsed lookups of package data."
 		print
 		print "       "+green("--prune")+" ("+green("-P")+" short option)"
@@ -94,11 +99,17 @@ def help(myaction,myopts,havecolor=1):
 		print "              users as rsync updates the cache using server-side caches."
 		print "              Rsync users should simply 'emerge --sync' to regenerate."
 		print
+		print "       "+green("--resume")
+		print "              Resumes the last merge operation. It can be treated just like a"
+		print "              regular emerge: --pretend and other options work alongside it."
+		print "              'emerge --resume' only returns an error on failure. When there is"
+		print "              nothing to do, it exits with a message and a success condition."
+		print
 		print "       "+green("--search")+" ("+green("-s")+" short option)"
-		print "              searches for matches of the supplied string in the current local"
-		print "              portage tree. The search string is a regular expression. Prepending"
-		print "              the expression with a '@' will cause the category to be included in"
-		print "              the search."
+		print "              Searches for matches of the supplied string in the current local"
+		print "              portage tree. The search string is a regular expression."
+		print "              Prepending the expression with a '@' will cause the category to"
+		print "              be included in the search."
 		print "              A few examples:"
 		print "              "+bold("emerge search '^kde'")
 		print "                  list all packages starting with kde"
@@ -107,25 +118,50 @@ def help(myaction,myopts,havecolor=1):
 		print "              "+bold("emerge search @^dev-java.*jdk")
 		print "                  list all available Java JDKs"
 		print
+		print "       "+green("--searchdesc")+" ("+green("-S")+" short option)"
+		print "              Matches the search string against the description field as well"
+		print "              the package's name. Take caution as the descriptions are also"
+		print "              matched as regular expressions."
+		print "                emerge -S html"
+		print "                emerge -S applet"
+		print "                emerge -S 'perl.*module'"
+		print
 		print "       "+green("--unmerge")+" ("+green("-C")+" short option)"
 		print "              "+turquoise("WARNING: This action can remove important packages!")
 		print "              Removes all matching packages "+bold("completely")+" from"
 		print "              your system. Specify arguments using the dependency specification"
 		print "              format described in the "+bold("--clean")+" action above."
 		print
-		print "       "+green("--config")
-		print "              Run package specific actions needed to  be  executed  after  the"
-		print "              emerge  process  has completed.  This usually entails configuration"
-		print "              file setup or other similar setups that the user  may  wish to run."
+		print "       "+green("--update")+" ("+green("-u")+" short option)"
+		print "              Updates packages to the best version available, which may not"
+		print "              always be the highest version number due to masking for testing"
+		print "              and development. This will also update direct dependencies which"
+		print "              may not what you want. In general use this option only in combi-"
+		print "              nation with the world or system target."
+		print
+		print "       "+green("--version")+" ("+green("-V")+" short option)"
+		print "              Displays the currently installed version of portage along with"
+		print "              other information useful for quick reference on a system. See"
+		print "              "+bold("emerge info")+" for more advanced information."
 		print
 		print turquoise("Options:")
+		print "       "+green("--alphabetical")
+		print "              When displaying USE and other flag output, combines the enabled"
+		print "              and disabled flags into a single list and sorts it alphabetically."
+		print "              With this option, output such as USE=\"dar -bar -foo\" will instead"
+		print "              be displayed as USE=\"-bar dar -foo\""
+		print
 		print "       "+green("--ask")+" ("+green("-a")+" short option)"
 		print "              before performing the merge, display what ebuilds and tbz2s will"
 		print "              be installed, in the same format as when using --pretend; then"
 		print "              ask whether to continue with the merge or abort. Using --ask is"
 		print "              more efficient than using --pretend and then executing the same"
 		print "              command without --pretend, as dependencies will only need to be"
-		print "              calculated once."
+		print "              calculated once. WARNING: If the \"Enter\" key is pressed at the"
+		print "              prompt (with no other input), it is interpreted as acceptance of"
+		print "              the first choice.  Note that the input buffer is not cleared prior"
+		print "              to the prompt, so an accidental press of the \"Enter\" key at any"
+		print "              time prior to the prompt will be interpreted as a choice!"
 		print
 		print "       "+green("--buildpkg")+" ("+green("-b")+" short option)"
 		print "              Tell emerge to build binary packages for all ebuilds processed"
@@ -174,7 +210,7 @@ def help(myaction,myopts,havecolor=1):
 		print "              used in combination with --pretend all the SRC_URIs will be"
 		print "              displayed multiple mirrors per line, one line per file."
 		print
-		print "       "+green("--fetch-all-uri")
+		print "       "+green("--fetch-all-uri")+" ("+green("-F")+" short option)"
 		print "              Same as --fetchonly except that all package files, including those"
 		print "              not required to build the package, will be processed."
 		print
@@ -194,6 +230,9 @@ def help(myaction,myopts,havecolor=1):
 		print "              Tells emerge to include installed packages where USE flags have "
 		print "              changed since installation."
 		print
+		print "       "+green("--nocolor")
+		print "              Suppresses color in the output."
+		print
 		print "       "+green("--noconfmem")
 		print "              Portage keeps track of files that have been placed into"
 		print "              CONFIG_PROTECT directories, and normally it will not merge the"
@@ -216,7 +255,7 @@ def help(myaction,myopts,havecolor=1):
 		print "       "+green("--nospinner")
 		print "              Disables the spinner regardless of terminal type."
 		print
-		print "       "+green("--oneshot")
+		print "       "+green("--oneshot")+" ("+green("-1")+" short option)"
 		print "              Emerge as normal, but don't add packages to the world profile."
 		print "              This package will only be updated if it is depended upon by"
 		print "              another package."
@@ -240,20 +279,6 @@ def help(myaction,myopts,havecolor=1):
 		print "              Effects vary, but the general outcome is a reduced or condensed"
 		print "              output from portage's displays."
 		print
-		print "       "+green("--resume")
-		print "              Resumes the last merge operation. Can be treated just like a"
-		print "              regular merge as --pretend and other options work along side."
-		print "              'emerge --resume' only returns an error on failure. Nothing to"
-		print "              do exits with a message and a success condition."
-		print
-		print "       "+green("--searchdesc")+" ("+green("-S")+" short option)"
-		print "              Matches the search string against the description field as well"
-		print "              the package's name. Take caution as the descriptions are also"
-		print "              matched as regular expressions."
-		print "                emerge -S html"
-		print "                emerge -S applet"
-		print "                emerge -S 'perl.*module'"
-		print
 		print "       "+green("--skipfirst")
 		print "              This option is only valid in a resume situation. It removes the"
 		print "              first package in the resume list so that a merge may continue in"
@@ -267,13 +292,6 @@ def help(myaction,myopts,havecolor=1):
 		print "              a package's dependencies follow the package. Only really useful"
 		print "              in combination with --emptytree, --update or --deep."
 		print
-		print "       "+green("--update")+" ("+green("-u")+" short option)"
-		print "              Updates packages to the best version available, which may not"
-		print "              always be the highest version number due to masking for testing"
-		print "              and development. This will also update direct dependencies which"
-		print "              may not what you want. In general use this option only in combi-"
-		print "              nation with the world or system target."
-		print
 		print "       "+green("--usepkg")+" ("+green("-k")+" short option)"
 		print "              Tell emerge to use binary packages (from $PKGDIR) if they are"
 		print "              available, thus possibly avoiding some time-consuming compiles."
@@ -291,12 +309,7 @@ def help(myaction,myopts,havecolor=1):
 		print "              Effects vary, but the general outcome is an increased or expanded"
 		print "              display of content in portage's displays."
 		print
-		print "       "+green("--version")+" ("+green("-V")+" short option)"
-		print "              Displays the currently installed version of portage along with"
-		print "              other information useful for quick reference on a system. See"
-		print "              "+bold("emerge info")+" for more advanced information."
-		print
-	elif myaction in ["rsync","sync"]:
+	elif myaction == "sync":
 		print
 		print bold("Usage: ")+turquoise("emerge")+" "+turquoise("--sync")
 		print
@@ -329,6 +342,18 @@ def help(myaction,myopts,havecolor=1):
 		print "       good idea to do an \"emerge --pretend system\" before an \"emerge"
 		print "       system\", just so you know what emerge is planning to do."
 		print
+	elif myaction=="world":
+		print
+		print bold("Usage: ")+turquoise("emerge")+" [ "+green("options")+" ] "+turquoise("world")
+		print
+		print "       'emerge world' is the Portage command for completely updating your"
+		print "       system.  The normal procedure is to first do an 'emerge --sync' and"
+		print "       then an 'emerge --update --deep world'.  The first command brings your"
+		print "       local Portage tree up-to-date with the latest version information and"
+		print "       ebuilds.  The second command then rebuilds all packages for which newer"
+		print "       versions or newer ebuilds have become available since you last did a"
+		print "       sync and update."
+		print
 	elif myaction=="config":
 		outstuff=green("Config file management support (preliminary)")+"""
 
@@ -367,8 +392,9 @@ add this to /etc/make.conf:
 
 CONFIG_PROTECT_MASK="/etc/wget /etc/rc.d"
 
-etc-update is also available to aid in the merging of these files. It provides
-a vimdiff interactive merging setup and can auto-merge trivial changes.
+Tools such as dispatch-conf, cfg-update, and etc-update are also available to
+aid in the merging of these files. They provide interactive merging and can
+auto-merge trivial changes.
 
 """
 		print outstuff
