@@ -12,152 +12,86 @@ class PortageException(Exception):
 
 class CorruptionError(PortageException):
 	"""Corruption indication"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class InvalidDependString(PortageException):
 	"""An invalid depend string has been encountered"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class InvalidVersionString(PortageException):
 	"""An invalid version string has been encountered"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class SecurityViolation(PortageException):
 	"""An incorrect formatting was passed instead of the expected one"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class IncorrectParameter(PortageException):
-	"""An parameter of the wrong type was passed"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
+	"""A parameter of the wrong type was passed"""
 
 class MissingParameter(PortageException):
-	"""An parameter is required for the action requested but was not passed"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
+	"""A parameter is required for the action requested but was not passed"""
 
+class ParseError(PortageException):
+	"""An error was generated while attempting to parse the request"""
 
 class InvalidData(PortageException):
 	"""An incorrect formatting was passed instead of the expected one"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class InvalidDataType(PortageException):
 	"""An incorrect type was passed instead of the expected one"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
-
-
-
 
 class InvalidLocation(PortageException):
 	"""Data was not found when it was expected to exist or was specified incorrectly"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class FileNotFound(InvalidLocation):
 	"""A file was not found when it was expected to exist"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class DirectoryNotFound(InvalidLocation):
 	"""A directory was not found when it was expected to exist"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
+class OperationNotPermitted(PortageException):
+	"""An operation was not permitted operating system"""
 
+class PermissionDenied(PortageException):
+	"""Permission denied"""
+
+class ReadOnlyFileSystem(PortageException):
+	"""Read-only file system"""
 
 class CommandNotFound(PortageException):
 	"""A required binary was not available or executable"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
-
 
 
 class PortagePackageException(PortageException):
 	"""Malformed or missing package data"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class PackageNotFound(PortagePackageException):
 	"""Missing Ebuild or Binary"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class InvalidPackageName(PortagePackageException):
 	"""Malformed package name"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
+class InvalidAtom(PortagePackageException):
+	"""Malformed atom spec"""
+
+class UnsupportedAPIException(PortagePackageException):
+	"""Unsupported API"""
+	def __init__(self, cpv, api):
+		self.cpv, self.api = cpv, api
+	def __str__(self):
+		return "Unable to do any operations on '%s', due to the fact it's EAPI is higher then this portage versions.  Please upgrade to a portage version that supports EAPI %s" % (self.cpv, self.eapi)
 
 
 
 class SignatureException(PortageException):
 	"""Signature was not present in the checked file"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class DigestException(SignatureException):
 	"""A problem exists in the digest"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class MissingSignature(SignatureException):
 	"""Signature was not present in the checked file"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class InvalidSignature(SignatureException):
 	"""Signature was checked and was not a valid, current, nor trusted signature"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
 class UntrustedSignature(SignatureException):
 	"""Signature was not certified to the desired security level"""
-	def __init__(self,value):
-		self.value = value[:]
-	def __str__(self):
-		return repr(self.value)
 
